==> agentchef-0.1.1-py3-none-any.whl: agentChef/__init__.py <==
"""
UDRAGS - Unified Dataset Research, Augmentation, & Generation System
=====================================================================

A comprehensive suite of tools for researching, generating, expanding, and cleaning 
conversation datasets powered by local Ollama models.

Main Components:
---------------
- OllamaConversationGenerator: Generate conversations from text content
- DatasetExpander: Create variations of existing conversation datasets
- DatasetCleaner: Identify and fix quality issues in datasets
- OllamaPandasQuery: Natural language querying of pandas DataFrames
- ResearchManager: Main interface for the research workflow

All components use local Ollama models, with no external API dependencies.
"""

__version__ = '0.1.0'

# Import main components
try:
    from .conversation_generator import OllamaConversationGenerator
    from .dataset_expander import DatasetExpander
    from .dataset_cleaner import DatasetCleaner
    from .pandas_query import OllamaPandasQuery
    from .UDRAGS import ResearchManager
except ImportError as e:
    import logging
    logging.warning(f"Error importing UDRAGS components: {e}")

# Check for required dependencies
try:
    import ollama
    HAS_OLLAMA = True
except ImportError:
    HAS_OLLAMA = False
    import logging
    logging.warning("Ollama not installed. Most functionality will be limited. Install with 'pip install ollama'")

# Optional UI components
try:
    from .ui import UdragsUI, run_ui
    HAS_UI = True
except ImportError:
    HAS_UI = False

__all__ = [
    'OllamaConversationGenerator',
    'DatasetExpander',
    'DatasetCleaner',
    'OllamaPandasQuery',
    'ResearchManager',
    'run_ui'
]

==> agentchef-0.2.0-py3-none-any.whl: agentChef/__init__.py <==
"""
UDRAGS - Unified Dataset Research, Augmentation, & Generation System
=====================================================================

A comprehensive suite of tools for researching, generating, expanding, and cleaning 
conversation datasets powered by local Ollama models.

Main Components:
---------------
- OllamaConversationGenerator: Generate conversations from text content
- DatasetExpander: Create variations of existing conversation datasets
- DatasetCleaner: Identify and fix quality issues in datasets
- OllamaPandasQuery: Natural language querying of pandas DataFrames
- ResearchManager: Main interface for the research workflow

All components use local Ollama models, with no external API dependencies.
"""

__version__ = '0.2.0'

# Import main components
try:
    from .conversation_generator import OllamaConversationGenerator
    from .dataset_expander import DatasetExpander
    from .dataset_cleaner import DatasetCleaner
    from .pandas_query import OllamaPandasQuery
    from ..agentChef.UDRAGS import ResearchManager
except ImportError as e:
    import logging
    logging.warning(f"Error importing UDRAGS components: {e}")

# Check for required dependencies
try:
    import ollama
    HAS_OLLAMA = True
except ImportError:
    HAS_OLLAMA = False
    import logging
    logging.warning("Ollama not installed. Most functionality will be limited. Install with 'pip install ollama'")

# Optional UI components
try:
    from .ui import UdragsUI, run_ui
    HAS_UI = True
except ImportError:
    HAS_UI = False

__all__ = [
    'OllamaConversationGenerator',
    'DatasetExpander',
    'DatasetCleaner',
    'OllamaPandasQuery',
    'ResearchManager',
    'run_ui'
]
